#!/bin/bash
#
# source: http://ftp.gnome.org/pub/gnome/sources/file-roller/
#
# maintainer: me
#

#------------------ Set Some Variables

NAME='file-roller'
VERSION=${VERSION:-$(echo $NAME-*.tar.?z* | rev | cut -f 3- -d . | cut -f 1 -d - | rev)}
arch="x86_64"
packageversion="1jp"

buildir=$(pwd)
srcpkg="$buildir/$NAME-$VERSION.tar.xz"
src="$buildir/$NAME-$VERSION"
package="$NAME-$VERSION-$arch-$packageversion"
PKG="/tmp/$package"

# ----------------- Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $PKG.tgz
rm -rf $PKG

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
 
if [ "$ARCH" = "i486" ]; then
  SLKCFLAGS="-O2 -march=i486 -mtune=i686"
  LIBDIRSUFFIX=""
elif [ "$ARCH" = "i686" ]; then
  SLKCFLAGS="-O2 -march=i686 -mtune=i686"
  LIBDIRSUFFIX=""
elif [ "$ARCH" = "x86_64" ]; then
  SLKCFLAGS="-O2 -fPIC"
  LIBDIRSUFFIX="64"
else
  SLKCFLAGS="-O2"
  LIBDIRSUFFIX=""
fi



CFLAGS="$SLKCFLAGS" \
./configure \
  --prefix=/usr \
  --libdir=/usr/lib${LIBDIRSUFFIX} \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --infodir=/usr/info \
  --docdir=/usr/doc/$PRGNAM-$VERSION \
  --localedir=/usr/share/locale \
  --enable-libarchive \
  --disable-nautilus-actions \
  --disable-static \
  --enable-shared 

make -j6 
make install DESTDIR=$PKG

find $PKG | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null


# Reset / Verify correct permissions
     ( cd $PKG/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $PKG/etc/gconf ; find . -type f -exec chmod 644 {} \; )

# fix desktop
(
cd $PKG/usr/share/applications
mv org.gnome.FileRoller.desktop file-roller.desktop
)

# Documentation

mkdir -p $PKG/usr/doc/$NAME-$VERSION
cp -a \
  AUTHORS ChangeLog COPYING HACKING INSTALL MAINTAINERS NEWS README TODO \
  $PKG/usr/doc/$NAME-$VERSION

mkdir -p $PKG/install
cat << "EODESC" > $PKG/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

           |-----handy-ruler---------------------------------------------------|
file-roller: file-roller - is an archive manager for the GNOME desktop
file-roller:
file-roller: File Roller is an archive manager for the GNOME environment. This
file-roller: means that you can create and modify archives; view the content
file-roller: of an archive; view and modify a file contained in the archive;
file-roller: extract files from the archive.
file-roller:
file-roller:
file-roller:
file-roller:
file-roller:
EODESC

cat << DOINST > $PKG/install/doinst.sh
if [ -x /usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/gtk-update-icon-cache ]; then
  usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
fi

if [ -x /usr/bin/glib-compile-schemas ]; then
  usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
fi
DOINST

mkdir -p $PKG/usr/src/$NAME-$VERSION
cp $buildir/build-$NAME.sh $PKG/usr/src/$NAME-$VERSION

# Packaging

cd $PKG
makepkg -l y -c n $PKG.txz
rm -rf $PKG
rm -rf $src
cd $buildir
